@@ -8,6 +8,8 @@
 # now can potentially shift the whole compose to a different version.
 PRODUCT_NAME="Container-native virtualization"
 
+echo "CI_CONTAINER_RELEASE=${CI_CONTAINER_RELEASE}"
+
 if [ -z "$CPAAS_PRODUCT_VERSION" ]; then
     echo "CPAAS_PRODUCT_VERSION is unset, trying to guess its value from HYPERCONVERGED_CLUSTER_OPERATOR_IMAGE_PULL_URL"
     case "$HYPERCONVERGED_CLUSTER_OPERATOR_IMAGE_PULL_URL" in
@@ -20,9 +22,15 @@ if [ -z "$CPAAS_PRODUCT_VERSION" ]; then
         *2\.3\.0*)
                   CPAAS_PRODUCT_VERSION="2.3.0"
         ;;
+        *2\.3\.1*)
+                  CPAAS_PRODUCT_VERSION="2.3.1"
+        ;;
         *2\.4\.0*)
                   CPAAS_PRODUCT_VERSION="2.4.0"
         ;;
+        *2\.5\.0*)
+                  CPAAS_PRODUCT_VERSION="2.5.0"
+        ;;
         *)
                   echo "FATAL: CPAAS_PRODUCT_VERSION is unset and I also failed guessing its value from HYPERCONVERGED_CLUSTER_OPERATOR_IMAGE_PULL_URL"
                   exit 2
@@ -46,12 +54,21 @@ case ${CPAAS_PRODUCT_VERSION} in
 #         IMAGE_SHA_DIGEST=false
 #  ;;
   2.3.0)
-         REPLACES_PRODUCT_VERSION="2.2.0"
+         echo "2.3.0 got already released; ignoring any other update"
+         exit 2
+  ;;
+#  2.3.1)
+#         REPLACES_PRODUCT_VERSION="2.3.0"
+#         IMAGE_SHA_DIGEST=true
+#  ;;
+  2.4.0)
+         REPLACES_PRODUCT_VERSION="2.3.0"
+         PRODUCT_NAME="Container-native virtualization"
          IMAGE_SHA_DIGEST=true
   ;;
-#  2.4.0)
-#         REPLACES_PRODUCT_VERSION="2.3.0"
-#         PRODUCT_NAME="OpenShift virtualization"
+#  2.5.0)
+#         REPLACES_PRODUCT_VERSION="2.4.0"
+#         PRODUCT_NAME="Container-native virtualization"
 #         IMAGE_SHA_DIGEST=true
 #  ;;
   *)
@@ -70,6 +87,7 @@ EOM
 )
 readonly machineType=pc-q35-rhel8.2.0
 
+
 if [ -z "$MANUAL_BUILD" ]
 then
   hco_image_pipeline="${HYPERCONVERGED_CLUSTER_OPERATOR_IMAGE_PULL_URL:?}"
@@ -112,8 +130,9 @@ clean_env(){
 
 init_env(){
     clean_env
-    mkdir CSVs
-    mkdir CRDs
+    mkdir -p CSVs
+    mkdir -p CRDs
+    mkdir -p "${BUNDLE_DIR}"
 }
 
 
@@ -145,6 +164,20 @@ metadataDescription="Creates and maintains a CNV Deployment"
 crdDisplay="CNV Operator"
 targetNamespace="openshift-cnv"
 
+virt_operator_version=$(echo ${VIRT_OPERATOR_BUILD_INFO_JSON} | python3 -c 'import json,sys;obj=json.load(sys.stdin);print(obj["extra"]["image"]["index"]["pull"][0].split("@")[1])')
+cnao_version=$(echo ${CLUSTER_NETWORK_ADDONS_OPERATOR_BUILD_INFO_JSON} | python3 -c 'import json,sys;obj=json.load(sys.stdin);print(obj["extra"]["image"]["index"]["pull"][0].split("@")[1])')
+
+CVERSIONS=$(cat <<- EOM
+--kubevirt-version=${virt_operator_version}
+--cdi-version=v${CPAAS_PRODUCT_VERSION}
+--cnao-version=${cnao_version}
+--ssp-version=v${CPAAS_PRODUCT_VERSION}
+--nmo-version=v${CPAAS_PRODUCT_VERSION}
+--hppo-version=v${CPAAS_PRODUCT_VERSION}
+--vm-import-version=v${CPAAS_PRODUCT_VERSION}
+EOM
+)
+
 case ${CPAAS_PRODUCT_VERSION} in
   2.2.0)
       CSV_OVERRIDES=""
@@ -152,6 +185,9 @@ case ${CPAAS_PRODUCT_VERSION} in
       TNAMESPACE=""
       SMBIOS=""
       MACHINETYPE=""
+      HCOKVVERSION=""
+      IMPORT_CSV=""
+      CVERSIONS_P=""
   ;;
   2.2.1)
       CSV_OVERRIDES=""
@@ -159,6 +195,9 @@ case ${CPAAS_PRODUCT_VERSION} in
       TNAMESPACE=""
       SMBIOS=""
       MACHINETYPE=""
+      HCOKVVERSION=""
+      IMPORT_CSV=""
+      CVERSIONS_P=""
   ;;
   2.3.0)
       CSV_OVERRIDES="--csv-overrides=${csvOverrides23}"
@@ -166,6 +205,9 @@ case ${CPAAS_PRODUCT_VERSION} in
       TNAMESPACE="--namespace=${targetNamespace}"
       SMBIOS=""
       MACHINETYPE=""
+      HCOKVVERSION=""
+      IMPORT_CSV=""
+      CVERSIONS_P=""
   ;;
   2.3.1)
       CSV_OVERRIDES="--csv-overrides=${csvOverrides23}"
@@ -173,6 +215,9 @@ case ${CPAAS_PRODUCT_VERSION} in
       TNAMESPACE="--namespace=${targetNamespace}"
       SMBIOS=""
       MACHINETYPE=""
+      HCOKVVERSION=""
+      IMPORT_CSV=""
+      CVERSIONS_P=""
   ;;
   *)
       CSV_OVERRIDES="--csv-overrides=${csvOverrides24}"
@@ -180,18 +225,22 @@ case ${CPAAS_PRODUCT_VERSION} in
       TNAMESPACE="--namespace=${targetNamespace}"
       SMBIOS="--smbios=${SMBios}"
       MACHINETYPE="--machinetype=${machineType}"
+      HCOKVVERSION="--hco-kv-io-version=v${CPAAS_PRODUCT_VERSION}"
       csvOverrides=$(get_fcontent "csvOverrides24.yaml")
       specDescription=$(get_fcontent "description24.txt")
-      specDisplayName="OpenShift virtualization"
-      metadataDescription="Creates and maintains an OpenShift virtualization Deployment"
-      crdDisplay="OpenShift virtualization Operator"
+      specDisplayName="OpenShift Virtualization"
+      metadataDescription="Creates and maintains an OpenShift Virtualization Deployment"
+      crdDisplay="OpenShift Virtualization Operator"
+      importCsv=$(get_fcontent "CSVs/vm-import-operator-container.csv")
+      IMPORT_CSV="--vmimport-csv=${importCsv}"
+      CVERSIONS_P=${CVERSIONS}
   ;;
 esac
 
 
 clean_old_crd(){
     if [ "${CPAAS_PRODUCT_VERSION}" != "2.2.1" ]; then
-        rm "${BUNDLE_DIR}"/*.crd.y*ml
+        rm -f "${BUNDLE_DIR}"/*.crd.y*ml
     fi
 }
 
@@ -211,6 +260,8 @@ run_with_oc(){
         --cdi-csv="${cdiCsv}" \
         --nmo-csv="${nmoCsv}" \
         --hpp-csv="${hppCsv}" \
+        "${IMPORT_CSV}" \
+        ${CVERSIONS_P} \
         --ims-conversion-image-name="${ims_v2v_image}" \
         --ims-vmware-image-name="${ims_vmware_image}" \
         --operator-image-name="${hco_image_csv}" \
@@ -225,6 +276,7 @@ run_with_oc(){
         "${TNAMESPACE}" \
 	"${SMBIOS}" \
         "${MACHINETYPE}" \
+        "${HCOKVVERSION}" \
     | sed -e "s/\r//" > "${TEMP_CSV_FILE_PATH}"
 
     clean_old_crd
@@ -246,6 +298,8 @@ run_with_docker(){
         --cdi-csv="${cdiCsv}" \
         --nmo-csv="${nmoCsv}" \
         --hpp-csv="${hppCsv}" \
+        "${IMPORT_CSV}" \
+        ${CVERSIONS_P} \
         --ims-conversion-image-name="${ims_v2v_image}" \
         --ims-vmware-image-name="${ims_vmware_image}" \
         --operator-image-name="${hco_image_csv}" \
@@ -260,6 +314,7 @@ run_with_docker(){
         "${TNAMESPACE}" \
 	"${SMBIOS}" \
         "${MACHINETYPE}" \
+        "${HCOKVVERSION}" \
     | sed -e "s/\r//" > "${TEMP_CSV_FILE_PATH}"
 
     clean_old_crd
